gabsurd/utility

Cleanup and utility operations for the Absurd durable workflow system.

Types

Result of a cleanup operation for a single queue.

pub type CleanupResult {
  CleanupResult(
    queue_name: String,
    tasks_deleted: Int,
    events_deleted: Int,
  )
}

Constructors

  • CleanupResult(
      queue_name: String,
      tasks_deleted: Int,
      events_deleted: Int,
    )

Values

pub fn cleanup_queue(
  db: client.Db,
  queue_name: String,
) -> Result(List(CleanupResult), client.GabsurdError)

Run cleanup for a specific queue (deletes old completed/failed tasks and processed events).

pub fn get_schema_version(
  db: client.Db,
) -> Result(String, client.GabsurdError)

Get the schema version from the database.

Search Document